@@ -1,3 +1,6 @@
+from uuid import uuid4
+
+
 def normalize_whitespace(text, base_whitespace: str = " ") -> str:
     """ Convert all whitespace to *base_whitespace* """
     return base_whitespace.join(text.split()).strip()
@@ -10,4 +13,8 @@ def strip_terminating_semicolon(sql: str) -> str:
 
 def escape_colon(sql: str) -> str:
     """Escapes colons for for use in sqlalchemy.text"""
-    return sql.replace(":", "\:")
+    holder = str(uuid4())
+    sql = sql.replace("::", holder)
+    sql = sql.replace(":", "\:")
+    sql = sql.replace(holder, "::")
+    return sql
